==> easybuild-framework-2.8.1.tar.gz: easybuild-framework-2.8.1/easybuild/tools/module_naming_scheme/migrate_from_eb_to_hmns.py <==
##
# Copyright 2013-2016 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# http://github.com/hpcugent/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
Implementation of a module naming scheme that can be used to migrate from EasyBuildMNS to HierarchicalMNS.

@author: Kenneth Hoste (Ghent University)
"""
from easybuild.tools.module_naming_scheme.easybuild_mns import EasyBuildMNS
from easybuild.tools.module_naming_scheme.hierarchical_mns import HierarchicalMNS

class MigrateFromEBToHMNS(HierarchicalMNS, EasyBuildMNS):

    def det_install_subdir(self, ec):
        """Determine name of software installation subdirectory of install path, using EasyBuild MNS."""
        return EasyBuildMNS.det_full_module_name(self, ec)

==> easybuild-framework-2.9.0.tar.gz: easybuild-framework-2.9.0/easybuild/tools/module_naming_scheme/migrate_from_eb_to_hmns.py <==
##
# Copyright 2013-2016 Ghent University
#
# This file is part of EasyBuild,
# originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
# with support of Ghent University (http://ugent.be/hpc),
# the Flemish Supercomputer Centre (VSC) (https://www.vscentrum.be),
# Flemish Research Foundation (FWO) (http://www.fwo.be/en)
# and the Department of Economy, Science and Innovation (EWI) (http://www.ewi-vlaanderen.be/en).
#
# http://github.com/hpcugent/easybuild
#
# EasyBuild is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation v2.
#
# EasyBuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
##
"""
Implementation of a module naming scheme that can be used to migrate from EasyBuildMNS to HierarchicalMNS.

:author: Kenneth Hoste (Ghent University)
"""
from easybuild.tools.module_naming_scheme.easybuild_mns import EasyBuildMNS
from easybuild.tools.module_naming_scheme.hierarchical_mns import HierarchicalMNS

class MigrateFromEBToHMNS(HierarchicalMNS, EasyBuildMNS):

    def det_install_subdir(self, ec):
        """Determine name of software installation subdirectory of install path, using EasyBuild MNS."""
        return EasyBuildMNS.det_full_module_name(self, ec)
